function [rgwkcl_mat] = model2_run(DELTA,ALFA,BETTA,G,SIGM,LAMBDAP,LAMBDAZ,...
    sigma_Z,sigma_P,MU,FRISCHELAS,STEADYSTATEL,T,shock,k0_mult,MultiplicativeU,...
    startopposite,regimechanges,regime_change_frequency,randomseq,order,spec)

% clear all


hardcode_irf_T = 100;

use_SchmittGrohe_Uribe_Matlab_code_to_find_coefficients = true;

defaults = {0.08,0.32,0.98,1.014,...
    0.9,0.95,0.92,0.017,...
    0.03,0.086,0.5,0.3,...
    200,"historical",1,1,...
    1,0,50,2,4,...
    "exactly0butwithrealshocks"}; % "sffedFirmSpecificLambdas_MIT"};

var = ["DELTA","ALFA","BETTA","G",...
       "SIGM","LAMBDAP","LAMBDAZ","sigma_Z",...
       "sigma_P","MU","FRISCHELAS","STEADYSTATEL",...
       "T","shock","k0_mult","MultiplicativeU",...
       "startopposite","regimechanges","regime_change_frequency","randomseq","order",...
       "spec"];

for i = 1:length(defaults)
    if ~exist(var{i},"var")
        if class(defaults{i}) == "string"
            eval(sprintf('%s = "%s";',var(i),defaults{i}))
        else
            eval(sprintf("%s = %g;",var(i),defaults{i}))
        end
        if i == 1
            addpath("../../../All Book Code/Chapter 2/Base Model/casadi-windows-matlabR2016a-v3.5.5")
            import casadi.*
        end
    end
end

folder = fileparts(which(mfilename));
addpath(join([folder,'\','MyHelperFunctions'],""))
addpath(join([folder,'\','SchmittGroheUribeHelperFunctions'],""))

if MultiplicativeU
    u = multiplicative_u;
    utility_function_str = "Multiplicative";
else
    u = additive_u;
    utility_function_str = "Additive";
end

max_order_I_can_handle = 4;
% nstates_plus_shocks = 10;
if use_SchmittGrohe_Uribe_Matlab_code_to_find_coefficients
    SchmittGrohe_decision_func = "SchmittGrohe";
    max_order_I_can_handle = 2;
else
    SchmittGrohe_decision_func = "";
end

decision_func_to_use = str2func(join(["decision_func_","order",max_order_I_can_handle,SchmittGrohe_decision_func],""));



Psifilenames = append(["../Parameterizations/largest_firms_"],...
    ["vcov", "shocks", "AR_coefs"], ["_"], [spec], [".csv"]);
[Psi_vcovFile, PsiShockFile, LAMBDAPsiFile] = deal(Psifilenames{:});
   
Psi_vcov = readmatrix(Psi_vcovFile);
LAMBDAPsi = readmatrix(LAMBDAPsiFile);


n_Psis = size(Psi_vcov, 1);


LAMBDAPhigh = 0.95;
LAMBDAPlow = 0.8;
if LAMBDAP == LAMBDAPhigh
    LAMBDAPopposite = LAMBDAPlow;
end
if LAMBDAP == LAMBDAPlow
    LAMBDAPopposite = LAMBDAPhigh;
end

PSISTAR = 1;
PHISTAR = 1; %phi_func(PSISTARS, P / (P - 1));
ZSTAR = 1;
PSISTARS = zeros([1 n_Psis]) + PSISTAR;

sym_labor_supply = laborsupply(u);
intertemporal_euler_ss = dupdcp_over_dudc(u,1);
intertemporal_euler_sym = dupdcp_over_dudc(u,0);

value_of_P_where_LSTAR_equals_STEADYSTATEL = G^(1/(1-LAMBDAPlow));

[~,~,~,~,~,GAMA,ETA]=model2_ss_numericsetGAMAandETA(DELTA,ALFA,BETTA,G,value_of_P_where_LSTAR_equals_STEADYSTATEL,FRISCHELAS,STEADYSTATEL,SIGM,ZSTAR,PHISTAR,sym_labor_supply,intertemporal_euler_ss,u);
PSTAR = G^(1/(1-LAMBDAP));
[KSTAR_start,CSTAR_initial_guess,LSTAR_initial_guess,~,~]=model2_ss_numeric(1,0.3,0.3,DELTA,ALFA,BETTA,G,PSTAR,ETA,GAMA,SIGM,ZSTAR,PHISTAR,sym_labor_supply,intertemporal_euler_ss);

if startopposite
    PSTARopposite = G^(1/(1-LAMBDAPopposite));
    PSTAR = PSTARopposite;
    [KSTARopposite,~,~,~,~]=model2_ss_numeric(1,0.3,0.3,DELTA,ALFA,BETTA,G,PSTARopposite,ETA,GAMA,SIGM,ZSTAR,PHISTAR,sym_labor_supply,intertemporal_euler_ss);
    KSTAR_start = KSTARopposite;
end

if string(shock) == "historical_french_data" || string(shock) == "historical_french_data_endogenous_P"
    tfpfile = "frenchTFP";
else
    tfpfile = "../Parameterizations/TFPshocks_sffed.csv";
end



% get_coefs_SchmittGrohe_Uribe

Z = ZSTAR; Z1 = ZSTAR; Z2 = ZSTAR; Z3 = ZSTAR; Zp = ZSTAR; Z1p = ZSTAR; Z2p = ZSTAR; Z3p = ZSTAR;
phihat = PHISTAR; phihatp = PHISTAR;


% k=KSTAR; c=CSTAR; l=LSTAR;
% kp=k; cp=c; lp=l;
% stockSTAR = G*((PSTAR-1)/PSTAR)*y_func(KSTAR,LSTAR,ZSTAR,ALFA,PHISTAR)/((1+RSTAR) - G); stock = stockSTAR; stockp = stockSTAR;
% lhat = LSTAR; lhatp = lhat;

for var = ["Psi_tminus1", "Psi_tminus1p", "Psi", "Psip"]
    for i = 1:n_Psis
        eval(sprintf('%s%d=PSISTARS(%d);',var,i,i))
    end
end

for i = 1:n_Psis
   eval(sprintf('%s%d=LAMBDAPsi(%d);',"LAMBDAPsi",i,i))
end


eta_without_Psis = [0 0; 1 0; 0 0; 0 0; 0 0; 0 sigma_P/sigma_Z]; %Matrix defining driving force
[n_non_Psi_states, n_non_Psi_shocks] = size(eta_without_Psis);
eta_stage1 = zeros([n_non_Psi_states + n_Psis n_non_Psi_shocks + n_Psis]);
eta_stage1(1:n_non_Psi_states,1:n_non_Psi_shocks) = eta_without_Psis;
eta_stage1((n_non_Psi_states + 1):(n_non_Psi_states + n_Psis), (n_non_Psi_shocks + 1):(n_non_Psi_shocks + n_Psis)) = Psi_vcov/sigma_Z;

flatten = @(A) A(:);

[fx,fxp,fy,fyp,fypyp,fypy,fypxp,fypx,fyyp,fyy,fyxp,fyx,fxpyp,fxpy,fxpxp,fxpx,fxyp,fxy,fxxp,fxx,f] = stage1model(u, n_Psis);

approx = order;

syms P Pp KSTAR CSTAR LSTAR RSTAR

%Obtain numerical derivatives of f
num_eval_symbolic
num_eval_out_stage1 = matlabFunction(sfx, sfxp, sfy, sfyp, sfypyp, sfypy, sfypxp, sfypx, sfyyp, sfyy, sfyxp, sfyx, sfxpyp, sfxpy, sfxpxp, sfxpx, sfxyp, sfxy, sfxxp, sfxx);

eta_stage2 = [eta_stage1;zeros([1 size(eta_stage1,2)])]; %adding lhat state variable



rng(13466910+randomseq,"twister");
rho_Z = normrnd(0,sigma_Z,[1 T]);
if ~(string(shock) == "none"||string(shock) == "historical"|| string(shock) == "historical_endogenous_P")
    rho_Z(1:5)=shock;
end

rng(222190+randomseq,"twister");
rho_Psis = mvnrnd(zeros([1 n_Psis]),Psi_vcov,T);

rho_P = zeros([T 1]);

if (string(shock) == "historical" || string(shock) == "historical_endogenous_P")
    T = 37;
    realTFPshocks = readmatrix(tfpfile);
    rho_Z = zeros([1 T]) + realTFPshocks(realTFPshocks(:,1)>1980.5&realTFPshocks(:,1)<2017.5,2)';
    if spec ~= "exactly_0" && spec ~= "exactly_004"
        realPsiShocks = readmatrix(PsiShockFile);
        rho_Psis = zeros([T n_Psis]) + realPsiShocks(realPsiShocks(:,1)>1980.5&realPsiShocks(:,1)<2017.5,2:size(realPsiShocks, 2));
    end
    if string(shock) == "historical"
        realProfits = readmatrix("../Parameterizations/ProfitShare.csv");
        True_P_Path = (1./(1-realProfits(realProfits(:,1)>1980.5&realProfits(:,1)<2017.5,2)))';
    end
end


k_sim = zeros([T 1]) + KSTAR_start;
Z_sim = zeros([T 1]) + ZSTAR;
P_sim = zeros([T 1]) + PSTAR;
Psis_sim = repmat(PSISTARS,T,1);
phihat_sim = zeros([T 1]) + PHISTAR;


c_sim = NaN([T 1]);
l_sim = NaN([T 1]);
stock_sim = NaN([T 1]);


for i=1:T
    Z_sim(i)=Z_sim(max(i-1,1))^LAMBDAZ*exp(rho_Z(i));
    P_sim(i) = True_P_Path(i);
    Psis_sim(i,:) = Psis_sim(max(i-1,1),:) .^ LAMBDAPsi .* exp(rho_Psis(i,:));
end
 
state_vars_stage1 = [k_sim,Z_sim,Z_sim,Z_sim,Z_sim,P_sim,Psis_sim];
state_vars_stage2 = [state_vars_stage1,l_sim];

   

% dec_ks = NaN([T 1 + (3 + n_Psis) + (3 + n_Psis)^2 + 1]);
% dec_cs = NaN([T 1 + (3 + n_Psis) + (3 + n_Psis)^2 + 1]);
% dec_stocks = NaN([T 1 + (3 + n_Psis) + (3 + n_Psis)^2 + 1]);
% dec_l_hats = NaN([T 1 + (2 + n_Psis) + (2 + n_Psis)^2 + 1]);
% dec_phihats = NaN([T 1 + (2 + n_Psis) + (2 + n_Psis)^2 + 1]);

% save num_eval_out_stage1.mat num_eval_out_stage1
% addAttachedFiles(gcp,{'num_eval_out_stage1.mat'})
%     num_eval_out_stage1 = load('num_eval_out_stage1.mat').num_eval_out_stage1

[dec_k, dec_c, dec_stock, dec_l_hat, dec_phihat] = ...
        get_decision_functions(PSTAR, num_eval_out_stage1, order, eta_stage1, eta_stage2,...
        CSTAR_initial_guess, LSTAR_initial_guess, DELTA, ALFA, BETTA, G, ETA, GAMA, SIGM, LAMBDAP, MU, ZSTAR,...
        PHISTAR, sym_labor_supply, intertemporal_euler_ss, LAMBDAZ, sigma_Z, PSISTARS, n_Psis, LAMBDAPsi, u, decision_func_to_use);

for i=1:T
    
    ssvals_stage1 = [dec_k(1),ZSTAR,ZSTAR,ZSTAR,ZSTAR,PSTAR,PSISTARS]; %different steady states depending on PSTAR (dec_k(1) = KSTAR)
    ssvals_stage2 = [ssvals_stage1, dec_l_hat(1)];  % dec_l_hat(1) = LSTAR
       
    state_vars_stage1(i,:) = [k_sim(i),Z_sim(i),Z_sim(i),Z_sim(i),Z_sim(i),P_sim(i),Psis_sim(max(i-1,1),:)];


    l_sim(i) = decision_func_to_use(dec_l_hat,state_vars_stage1(i,:),ssvals_stage1,sigma_Z);
    phihat_sim(i) = decision_func_to_use(dec_phihat,state_vars_stage1(i,:),ssvals_stage1,sigma_Z);
    
    state_vars_stage2(i,:) = [state_vars_stage1(i,1:n_non_Psi_states),Psis_sim(i,:),l_sim(i)];
    
    c_sim(i)=decision_func_to_use(dec_c,state_vars_stage2(i,:),ssvals_stage2,sigma_Z);
    stock_sim(i)=decision_func_to_use(dec_stock,state_vars_stage2(i,:),ssvals_stage2,sigma_Z);
    if i < T
        k_sim(i+1) = decision_func_to_use(dec_k,state_vars_stage2(i,:),ssvals_stage2,sigma_Z);
    end
    if i+1 == 5 && (string(shock) == "historical" || string(shock) == "historical_endogenous_P")
        k_sim(i+1) = KSTAR_start;
    end
    
end

theta_sim = P_sim ./ (P_sim - 1);
phi_sim = phi_func(Psis_sim, theta_sim);
% phihat_sim = phi_func([PSISTARS;Psis_sim(1:T-1,:)] .^ LAMBDAPsi, P_sim ./ (P_sim - 1));
w_sim = w_func(k_sim,l_sim,P_sim,Z_sim,ALFA,phihat_sim);
r_sim = little_r(k_sim,l_sim,P_sim,Z_sim,ALFA,DELTA,phihat_sim);
y_sim = y_func(k_sim,l_sim,Z_sim,ALFA,phi_sim);
g_sim = [NaN;(G*y_sim(2:T)-y_sim(1:T-1))./y_sim(1:T-1)];
profits_sim = ((P_sim-1)./P_sim).*y_sim;

rgwkcl_mat = [r_sim,g_sim,w_sim,k_sim,c_sim,l_sim,stock_sim,y_sim,phi_sim,phihat_sim,P_sim,Z_sim];

if (string(shock) == "historical" || string(shock) == "historical_endogenous_P")
    rgwkcl_mat = rgwkcl_mat(5:37,:);
    rgwkcl_mat(1,2) = NaN;
end

% writematrix(rgwkcl_mat,"rgwkcl_mat2.xlsx",'Sheet',1) %,'Range','B4')